@@ -22,6 +22,7 @@ NAME_RE = r"[a-zA-Z][-a-zA-Z0-9_]*"
 WHITELIST = frozenset([
     "translate",
     "domain",
+    "context",
     "target",
     "source",
     "attributes",
@@ -29,7 +30,8 @@ WHITELIST = frozenset([
     "name",
     "mode",
     "xmlns",
-    "xml"
+    "xml",
+    "comment",
     ])
 
 _interp_regex = re.compile(r'(?<!\$)(\$(?:(%(n)s)|{(%(n)s)}))'
