@@ -18,6 +18,7 @@ except ImportError:
 
 
 from chameleon.utils import byte_string
+from chameleon.exc import RenderError
 
 
 class Message(object):
@@ -369,7 +370,8 @@ class ZopePageTemplatesTest(RenderTestCase):
             )
         try:
             template()
-        except:
+        except Exception as exc:
+            self.assertIn(RenderError, type(exc).__bases__)
             exc = sys.exc_info()[1]
             formatted = str(exc)
             self.assertFalse('NameError:' in formatted)
@@ -614,9 +616,14 @@ class ZopeTemplatesTestSuite(RenderTestCase):
             else:
                 with_domain = " with domain '%s'" % domain
 
+            if context is None:
+                with_context = ""
+            else:
+                with_context = ", context '%s'" % context
+
             stripped = default.rstrip('\n ')
-            return "%s ('%s' translation into '%s'%s)%s" % (
-                stripped, msgid, target_language, with_domain,
+            return "%s ('%s' translation into '%s'%s%s)%s" % (
+                stripped, msgid, target_language, with_domain, with_context,
                 default[len(stripped):]
                 )
 
